docs.rs failed to build gossan-origin-0.3.3
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
gossan-origin-0.3.2
gossan-origin
Part of the Santh security research ecosystem.
Discovers the true origin IP of web assets behind CDNs/WAFs (part of the Santh security research ecosystem).
Part of gossan.
Usage
## Usage
```bash
# Discover real IP origins for a Cloudflare-protected domain
gossan origin example.com --passive --favicons
## License
MIT